#Each dictionary index refers to the location in the NMEA-sentence, the parameters refer to the OMC-DOL notation of "('Name', 'Unit',  'TAG')"
#Make sure the given TAGs are unique, the Name and Units can be chosen freely.

## NMEA_Message_NAME =  {       1:    ("Name1", "Unit1",  "TAG1" ),
##                              2:    ("Name2", "Unit2",  "TAG2" ),
##                              3:    ("Name3", "Unit3",  "TAG3" ),
##                              4:    ("Name4", "Unit4",  "TAG4" ),
##                              5:    ("Name5", "Unit5",  "TAG5" ),
##                              Etc.                                
##                      }

#Once the dictionary driver is created, the generic driver is defined in the config.txt as:

#generic_nmea:
#- id: nmea_gen0
#  port: serial1
#  nmea_sentence: VTG                            
#  sample_interval: "0,10,20,30,40,50 * * * *"
#  response_timeout: 60

#The generic nmea driver can decode more than one sentence by editting the "nmea_sentence:' line shown in the next example. 
#Make sure the sentences are only seperated by one comma as shown.

#generic_nmea:
#- id: nmea_gen0
#  port: serial1
#  reference_table: VTG,GGA,RMC                           
#  sample_interval: "0,10,20,30,40,50 * * * *"
#  response_timeout: 60

#The id, port, response_timeout, interval etc. need to be set accuratly matched to the setup of the sensor.
#At start-up the driver waits during the response_timeout to receive the sentence, if not defined this is 10 seconds as default.
#Use the 'sensor_data_print: True' setting to validate the data parsed by the generic nmea driver:

#  # ----System---- #
#  Omc048:
#    sensor_data_print: True

#If the "nmea_reference_table_template" file will be used, the "_template" part of the filename must be removed. 

class GenericReferenceNmea:

    GGA =       {       0:  ('Identifier','','ID'), 
                        1:  ('UTC', '', 'TIME'),
                        2:  ('Latitude', 'deg', 'LAT'),
                        3:  ('Dir of lat', '', 'DLAT'),
                        4:  ('Longitude', 'deg', 'LON'),
                        5:  ('Dir of lon', '', 'DLON'),
                        6:  ('Quality', '', 'GPSQ'),
                        7:  ('Satellites', '', 'SAT'),
                        8:  ('Hdop', 'm', 'HDOP'),
                        9:  ('Altitude', 'm', 'ALT'),
                       #10:  ('Altitude meters', '', 'ALTM'),
                       11:  ('Geoid sep', '', 'GEO'),
                       #12:  ('Geoid meters', '', 'GEOM'),
                       13:  ('Age', 'min', 'AGE'),
                       14:  ('Station', '', 'STAT')                       
                }

    PSVSW =       {     0:  ('Identifier','','ID'),                                               
                        1:  ('Heading', 'deg', 'HED'),
                        2:  ('SignificantWaveHeight', 'm', 'SWH'),
                        3:  ('DominantPeriodFW', 's', 'DPF'),
                        4:  ('WaveDirectionFW', 'deg', 'WDF'),
                        5:  ('MeanWaveDir', 'deg', 'MWD'),
                        6:  ('Hmax', 'm', 'HM1'),
                        7:  ('Hmax2', 'm', 'HM2'),
                        8:  ('Identity', '', 'IDT'),
                        9:  ('Date & Time', '', 'STAT'),
                        10:  ('Index', 'sample_nr', 'IDX'),
                }

    VTG =       {       0:  ('Identifier','','ID'), 
                        1:  ('Course true', 'deg', 'CRST'),
                        #2:  ('Course true T', '', 'CRSST'),
                        3:  ('Course magnetic', 'deg', 'CRSM'),
                        #4:  ('Course magnetic M', '', 'CRSMM'),
                        5:  ('Speed knots', 'knots', 'SPDK'),
                        #6:  ('Speed knots N', '', 'SPDKN'),
                        7:  ('Speed kmh', 'km/h', 'SPDM'),
                        #8:  ('Speed kmh K', '', 'SPDMK'),
                        9:  ('Mode', '', 'MOD')                       
                }

    RMC =       {       0:  ('Identifier','','ID'),                                   
                        1:  ('UTC', '', 'TIME'),
                        2:  ('Status', '', 'STS'),
                        3:  ('Latitude', 'deg', 'LAT'),
                        4:  ('Dir of lat', '', 'DLAT'),
                        5:  ('Longitude', 'deg', 'LON'),
                        6:  ('Dir of lon', '', 'DLON'),
                        7:  ('Speed knots', 'knots', 'SPDK'),
                        8:  ('Course true', 'deg', 'CRST'),
                        9:  ('Date', '', 'DATE'),
                       10:  ('Magnetic variation', 'deg', 'VAR'),
                       #11:  ('Dir of mag variation', '', 'DVAR'),
                       12:  ('Mode', '', 'MOD'),
                       13:  ('Nav status', '', 'NGST')                       
                }

    TXT =       {       #0:  ('Identifier','','ID'), 
                        1:  ('Number of sentences', '', 'NOS'),
                        2:  ('Sentence number', '', 'SENN'),
                        3:  ('Text id', '', 'TXID'),
                        4:  ('Message', '', 'MSSG')                  
                }

    PTID =       {      #0:  ('Identifier','','ID'), 
                        #1:  ('', '', ''),
                        #2:  ('', '', ''),
                        #3:  ('', '', ''),
                        4:  ('Depth', 'm', 'DEP'),
                        #5:  ('', '', ''),
                        6:  ('Status', '', 'STAT'),
                        7:  ('Battery voltage', 'V', 'VBAT'),
                        #8:  (' ', '', ''),
                        9:  ('Barometric pressure', 'hPa', 'BAR'),
                        #10: ('', '', '')                    
                }

