#New sensor drivers can be added by creating a new dictionary, with a user-chosen (driver) name (see tamplate example below)
#The sdi12 driver requires a DEVICE_ADDRESS, SEPARATOR, STOP and MEASUREMENT_COMMAND.
#These are defined at line 0 of the dictionary as : "0:   ("DEVICE_ADDRESS", "SEPARATOR", "STOP", "MEASUREMENT COMMAND"),
#It is possible to use multiple separators as:      "0:   ("DEVICE_ADDRESS", ["SEPARATOR1", "SEPARATOR2"], "STOP", "MEASUREMENT_COMMAND"),
#Each dictionary index refers to the location in the sentence, the parameters refer to the OMC-DOL notation of "('Name', 'Unit',  'TAG')"
#Make sure the given TAGs are unique, the Name and Units can be chosen freely.

#If multiple sensors are used on the sdi-12 bus, the MEASUREMENT_COMMAND should be a concurrent command, given by C!,CC!, Cx! or CCx!. (x = number of command)
#If only one sensor is used on the sdi-12 bus, the M!, MC!, Mx! and MCx! commands could also be used. 

## DICTIONARY_NAME =   {
##                         0:    ("DEVICE_ADDRESS", "SEPARATOR", "STOP", "MEASUREMENT_COMMAND"),
##                         1:    ("Name1", "Unit1",  "TAG1" ),
##                         2:    ("Name2", "Unit2",  "TAG2" ),
##                         3:    ("Name3", "Unit3",  "TAG3" ),
##                         4:    ("Name4", "Unit4",  "TAG4" ),
##                         5:    ("Name5", "Unit5",  "TAG5" ),
##                     }

#Once the dictionary driver is created, the generic driver is defined in the config.txt as:

#generic_sdi12:
# - id: sdi12_gen0
#   port: sdi12
#   baudrate: 1200
#   bits: 7
#   parity: 0
#   reference_table: PT12,PT2X
#   sample_interval: "0,10,20,30,40,50 * * * *"
#   response_timeout: 60

#It's possible to add multiple sensors to the bus, by adding the name of the dictionary driver to "reference_table:" in the config, as shown in the example above.

#The id, port, response_timeout, interval etc. need to be set accuratly matched to the setup of the sensor.
#At start-up the driver waits during the response_timeout to receive the sentence, if not defined this is 10 seconds as default.
#Use the 'sensor_data_print: True' setting to validate the data parsed by the generic sdi-12 driver

#  # ----System---- #
#  Omc048:
#    sensor_data_print: True

#If the "sdi12_reference_tables_template" file will be used, the "_template" part of the filename must be removed as well as the unused reference tables.

class  sdi_reference_table:
    PT12 =     {
                        0:    ('2', ['+','-'], '\r\n', 'CC!'),
                        1:    ("Pressure",       "PSIG",   "Pres" ),
                        2:    ("Temperature",    "C",     "Temp" ),
                        3:    ("Voltage",        "V",     "Volt" ),
                }

    PT2X =     {
                        0:    ("3", ['+','-'], '\r\n', 'CC!'),
                        1:    ("Temperature",    "C",     "Temp" ),                       
                        2:    ("Pressure",       "PSIG",   "Pres" ),
                }

    NEP5000 =  {
                        0:    ('1', ['+','-'], '\r\n', 'M!'),
                        1:    ("Turbidity", "NTU",  "Turb" )
                }

    EXO =     {
                        0:    ('2', ['+','-'] , '\r\n' , 'M!'),
                        1:    ("Temp",       "PSIG",   "Pres" ),
                        2:    ("Cond",    "C",     "Temp" ),
                        3:    ("PH",        "V",     "Volt" ),
                        4:    ("PHmv",       "PSIG1",   "Pres1" ),
                        5:    ("ORPmv",    "C1",     "Temp1" ),
                        6:    ("Depth",        "V1",     "Volt1" ),
                }

    T1 =     {
                        0:    ('2', ['+','-'], '\r\n', 'CC!'),
                        1:    ("N/A",      "",     "N/A" ),
                        2:    ("Temperature",    "C",     "Temp" ),
                        3:    ("Voltage",        "V",     "Volt" ),
                }

    Ponsel_ODO =     {
                        0:    ('2', ['+','-'], '\r\n', 'CC!'),
                        1:    ("Temperature",    "C",     "Temp" ),
                        2:    ("ODOsat %",       "%",     "ODOs" ),
                        3:    ("ODO mg/L",    "mg/L",     "ODOm" ),
                        4:    ("ODO ppm",      "ppm",     "ODOp" ),
                        5:    ("N/A",      "",     "N/A" ),
                }

    Ponsel_NepTU =     {
                        0:    ('2', ['+','-'], '\r\n', 'CC!'),
                        1:    ("Temperature",    "C",     "Temp" ),
                        2:    ("Turbid NTU",   "NTU",     "TURn" ),
                        3:    ("Turbid FNU",   "FNU",     "TURf" ),
                        4:    ("Turbid mg/L", "mg/L",     "TURm" ),
                        5:    ("N/A",      "",     "N/A" ),
                }

    Ponsel_pHEH =     {
                        0:    ('2', ['+','-'], '\r\n', 'CC!'),
                        1:    ("Temperature",    "C",     "Temp" ),
                        2:    ("pH",      "pH",     "PH" ),
                        3:    ("Orp mV",  "mV",   "ORPv" ),
                        4:    ("pH mV",   "mV",    "PHv" ),
                        5:    ("N/A",      "",     "N/A" ),
                }

    Ponsel_C4ET =     {
                        0:    ('2', ['+','-'], '\r\n', 'CC!'),
                        1:    ("Temperature",    "C",     "Temp" ),
                        2:    ("SpCond uS/cm",      "uS/cm",     "SPCu" ),
                        3:    ("Sal ppt",  "ppt",   "SALp" ),
                        4:    ("TDS_Kcl",   "ppm",    "TDSp" ),
                        5:    ("N/A",      "",     "N/A" ),
                }

    Ponsel_CTZT =     {
                        0:    ('2', ['+','-'], '\r\n', 'CC!'),
                        1:    ("Temperature",    "C",     "Temp" ),
                        2:    ("SpCond mS/cm",      "mS/cm",     "SPCm" ),
                        3:    ("Sal ppt",  "ppt",   "SALp" ),
                        4:    ("Cond mS/cm",   "mS/cm",    "CONm" ),
                        5:    ("N/A",      "",     "N/A" ),
                }                               
