#To add a new driver dictionary must be added with a user-chosen driver name (see template example below)
#The generic driver requires a START, SEPARATOR and STOP to define the message boundaries.
#These are defined at line 0 of the dictionary as : "0:   ('START', 'SEPARATOR', 'STOP'),"
#It is possible to use multiple separators as:      "0:   ('START', ('SEPARATOR1','SEPARATOR2',.....), 'STOP'),"
#If ascii notation is not possible, your can use hexadecimal notation as: '\x01\x02\x03\x04......'
#STOP, START and SEPARATOR can be a character or a string of characters.
#Each dictionary index refers to the location in the sentence, the parameters refer to the OMC-DOL notation of "('Name', 'Unit',  'TAG')"
#Make sure the given TAGs are unique, the Name and Units can be chosen freely.

## DICTIONARY_NAME =   {
##                         0:    ('START', 'SEPARATOR', 'STOP'),
##                         1:    ("Name1", "Unit1",  "TAG1" ),
##                         2:    ("Name2", "Unit2",  "TAG2" ),
##                         3:    ("Name3", "Unit3",  "TAG3" ),
##                         4:    ("Name4", "Unit4",  "TAG4" ),
##                         5:    ("Name5", "Unit5",  "TAG5" ),
##                     }

#Once the dictionary driver is created, the generic driver is defined in the config.txt as:

#generic_serial_input:
#- id: gen0
#  port: serial1
#  reference_table: DICTIONARY_NAME
#  sample_interval: "0,10,20,30,40,50 * * * *"
#  response_timeout: 60

#The id, port, response_timeout, interval etc. need to be set accordingly, the reference_table must match the given dictionary!
#At start-up the driver waits during the response_timeout to receive the sentence, if not defined this is 10 seconds as default.
#Use the 'sensor_data_print: True' setting to validate the data parsed by the generic serial driver

#  # ----System---- #
#  Omc048:
#    sensor_data_print: True

#If the "serial_reference_table_template" file will be used, the "_template" part of the filename must be removed. 

class GenericReference:

    GMX501 =    {
                        0:    ('\x02', ',', '\r\n'),
                        1:    ("Node Letter", "",  "NODE" ),
                        2:    ("Wind Direction", "deg",  "DIR" ),
                        3:    ("Wind Speed", "m/s",  "SPEED" ),
                        4:    ("Corrected Direction", "deg",  "CDIR" ),
                        5:    ("GPS Corrected Speed", "m/s",  "CSPEED" ),
                        6:    ("Pressure", "hPa",  "PRESS" ),
                        7:    ("Relative Humidity", "%",  "RH" ),
                        8:    ("Temperature", "C",  "TMP" ),
                        9:    ("Dewpoint", "C",  "DP" ),
                        10:   ("Solar Radiation", "W/m2",  "SOL" ),
                        11:   ("GPS data", "",  "GPS" ),
                        12:   ("Date & Time", "",  "TIME" ),
                        13:   ("Supply Voltage", "V",  "VOLT" ),
                        14:   ("Status", "",  "STATUS" ),
                        15:   ("Checksum", "",  "CHECK" )
                }

    GMX500 =    {
                        0:    ('\x02', (',',':','T'), '\r\n'),
                        1:    ("Node Letter", "",  "NODE" ),
                        2:    ("Wind Direction", "deg",  "DIR" ),
                        3:    ("Wind Speed", "m/s",  "SPEED" ),
                        4:    ("Corrected Direction", "deg",  "CDIR" ),
                        5:    ("Pressure", "hPa",  "PRESS" ),
                        6:    ("Relative Humidity", "%",  "RH" ),
                        7:    ("Temperature", "C",  "TEMP" ),
                        8:    ("Dewpoint", "C",  "DP" ),
                        9:    ("Solar Radiation", "W/m2",  "SOL" ),
                        10:   ("Date & Hours", "",  "TIME" ),
                        11:   ("Hours", "",  "HRS" ),
                        12:   ("Minutes", "",  "MIN" ),
                        13:   ("Seconds", "",  "SEC" ),
                        14:   ("Supply Voltage", "V",  "VOLT" ),
                        15:   ("Status", "",  "STATUS" ),
                        16:   ("Checksum", "",  "CHECK" )
                }

    TEM500 =    {
                        0:    ('#,', ',', '\x3B'),
                        1:    ("Sensor address", "", "ADDR"),
                        2:    ("CIB_Number", "",  "CIBNR" ),
                        3:    ("Temperature", "C",  "TEMP" )
                }

    QXX2150 =   {
                        0:    ('$,', ',', '\x0D\x0A'),
                        1:    ("Serial Number", "",  "SN" ),
                        2:    ("PAR", "uE/m2/sec", "PAR")
                } 
           
