# The generic_serial_output_driver is enabled via the config.txt file:

# #----Output-settings---- #
# generic_serial_output:
# - id: gen_out_uno
#   port: serial1		
#   baudrate: 9600
#   reference_table: example_convert,OMC2900
#   mode: RS232
#
# The other port settings are defined identically as is done with the sensor drivers. 
# Multiple ports can be defined by adding id's, as is done with the sensor drivers
#
# The reference table can be chosen from the examples below or configured/made by the user. 
# To add a new output string a dictionary must be added with a user-chosen name.
# The output_driver requires a START, SEPARATOR and STOP. Additionally a checksum function can be added, but this is not required
# for a functional output.
# These fields are defined at line 0 of the dictionary as follows:
# In case no checksum is used: "0:   ('START', 'SEPARATOR', 'STOP'),"
# In case a checksum is used: "0:   ('START', 'SEPARATOR', 'STOP', checksum_list.function),"
# 
# The checksum function  could also be designed/added by the user. When designing a checksum function, just make sure it returns the full string plus addition.
#
# The remaining items in de dictionary are filled with datafields to be converted and the output configuration.
# 
#  If 'sensor_data_print' is set to 'True' the USB REPL output will print all obtained sensor data.
#  This data is used to identify the required sensor data for gereric_serial_output.
#  'sensor_data_print' is found under:
#
#   # ----System---- #
#   Omc048:
#     sensor_data_print: True
#
# Output over usb example :
#
#     Sensor data: ('Int. Humidity', 'rh', 'IHUM') 20.11
#     Sensor data: ('Int. Temperature', 'C', 'ITEMP') 20.5
#     Sensor data: ('Int. Coin cell voltage', 'V', 'IVBAT') 3.14

# The parameter fields can be copied to the first item in the desired conversion dictionary as shown in the example below.
		# 1       :      	(('Int. Humidity', 'rh', 'IHUM'),               "HUMID:{:.3f}"),
		# 2       :      	(('Int. Temperature', 'C', 'ITEMP'),            "{:.3f}TEMP"),
		# 3       :      	(('Int. Coin cell voltage', 'V', 'IVBAT'),      "Coin:{:.3f}V"),
# 
# The second item in the remaing lines of the dictionary is the output configuration of the datafield. 
# The curly brackets in the field determine where the measured value will be placed. 
# If the curly brackets are left empty, the original value will be used
# if {:.xf} will be used, the value will be rounded to x decimals.
#Example: 3.3333 formatted with {:.2f} becomes 3.33

# If {:y<z} is used the datafield will be padded with y characters to match x values.  If y is left empty, spaces are used for padding.
#Example: 3.33 formatted with {:@<6} becomes @@3.33
#Example: 3.33 formatted with {:@>6} becomes 3.33@@
#
# The arguments inside the curly brackets can be combined to {:y<z.xf}
#    
#If the "serial_output_reference_tables" file will be used, the "_template" part of the filename must be removed. 
		
class reformat_output:
		def checksum_omc2900(self,message):
				return_data = ""
				message = ["\n{}".format(val) for val in message.split('\r') if val]
				for item in message:
					calc_message = "{} \r".format(item)
					it = iter(map(ord, calc_message))
					value = next(it)
					for element in it:
							value += element
					value = value % 0x100
					message_checksum = "{} {:02X}\r".format(item, value)
					return_data += message_checksum
				message_checksum = "\x01{}\x04\r\n".format(return_data)
				return message_checksum

		def sdi12_crc16(self, message):
				ba = bytearray(message, 'utf-8') if isinstance(message, str) else bytearray(message)
				crc = 0
				for b in ba:
						crc ^= b
						for _ in range(8):
								if (crc & 1):
										crc >>= 1
										crc ^= 0xA001
								else:
										crc >>= 1
				first =   0x40 | (crc >> 12)
				second =  0x40 | ((crc >> 6) & 0x3F)
				third =   0x40 | (crc & 0x3F)
				string = chr(first) + chr(second) + chr(third)
				message = "{}{}".format(message,string)
				return message

class  serial_output_reference_tables:
		checksum_list = reformat_output()
		example_convert 	=  	{
									0		:      	("START", ",", "STOP\r\n", checksum_list.sdi12_crc16),				
									1       :      	(('Int. Humidity', 'rh', 'IHUM'),               "HUMID:{:.3f}"),
									2       :      	(('Int. Temperature', 'C', 'ITEMP'),            "TEMP:{:.3f}"),
									3       :      	(('Int. Coin cell voltage', 'V', 'IVBAT'),      "Coin:{:.3f}V"),
								}

		OMC2900 			=	{
									0		:		("","\r", "", checksum_list.checksum_omc2900),					
									1       :      	(('Int. Humidity', 'rh', 'IHUM'),               "a{:.2f}"),
									2       :      	(('Int. Temperature', 'C', 'ITEMP'),            "b{:.2f}"),
									3       :      	(('Int. Coin cell voltage', 'V', 'IVBAT'),      "c{:.2f}"),
								}
